=========
changelog
=========

ver 0.1.2
=========

Fixes
-----

* Recover removed CLI-entrypoint from ver0.1.1

ver 0.1.1
=========

Change package builder.

.. note:: This version does not have feature-changings.

ver 0.1.0
=========

First release.

Features
--------

* Watch source directory
* When reST file are changed in source dir, Run sphinx-build
* Run HTTP server with option
